(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 * ****************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit KeywordEdit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Db, DBTables, ComCtrls, Menus, StdCtrls, Buttons, DBCtrls;

type
  TformKeywordEdit = class(TForm)
    menuMain: TMainMenu;
    menuFile: TMenuItem;
    menuFileReplace: TMenuItem;
    menuFileClose: TMenuItem;
    menuEdit: TMenuItem;
    menuEditClear: TMenuItem;
    menuHelp: TMenuItem;
    menuHelpInEnglish: TMenuItem;
    menuHelpInJapanese: TMenuItem;
    statusbarBottom: TStatusBar;
    tableKeyWord: TTable;
    groupboxReplace: TGroupBox;
    labelOldKeyword: TLabel;
    labelNewKeyowrd: TLabel;
    editNewKeyword: TEdit;
    groupboxAppend: TGroupBox;
    editAppendKeyword: TEdit;
    bitbtnReplace: TBitBtn;
    bitbtnAppend: TBitBtn;
    groupboxRemove: TGroupBox;
    bitbtnRemove: TBitBtn;
    bitbtnClose: TBitBtn;
    menuFileAppend: TMenuItem;
    menuFileRemove: TMenuItem;
    datasourceKeyword: TDataSource;
    listboxOldKeyword: TListBox;
    listboxRemoveKeyword: TListBox;
    tableAlbum: TTable;
    progressbarProcessing: TProgressBar;
    procedure menuFileCloseClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure menuFileAppendClick(Sender: TObject);
    procedure menuFileRemoveClick(Sender: TObject);
    procedure menuFileReplaceClick(Sender: TObject);
    procedure menuHelpInEnglishClick(Sender: TObject);
    procedure menuHelpInJapaneseClick(Sender: TObject);
  private
    procedure LoadKeywordToListBox(ListBox: TListBox);
    procedure EnableControls(EnabledFlag: Boolean);
  public
  end;

var
  formKeywordEdit: TformKeywordEdit;

implementation

uses main,ShellAPI;

{$R *.DFM}

procedure TformKeywordEdit.EnableControls(EnabledFlag: Boolean);
begin
  bitbtnReplace.Enabled:=EnabledFlag;
  bitbtnAppend.Enabled:=EnabledFlag;
  bitbtnRemove.Enabled:=EnabledFlag;
  bitbtnClose.Enabled:=EnabledFlag;
end;

procedure TformKeywordEdit.menuFileCloseClick(Sender: TObject);
begin
  Close;
end;


procedure TformKeywordEdit.LoadKeywordToListBox(ListBox: TListBox);
var
  I           : Longint;
  KeyWord     : String;
  NoOfRecords : Longint;
begin
  NoOfRecords:=tableKeyWord.RecordCount;
  if NoOfRecords>0 then begin
    tableKeyWord.First;
    ListBox.Clear;
    for I:=0 to NoOfRecords-1 do begin
      KeyWord:=tableKeyWord.FieldByName('KEYWORD').AsString;
      ListBox.Items.Add(KeyWord);
      tableKeyWord.Next;
    end;
  end;
  ListBox.Refresh;
end;




procedure TformKeywordEdit.FormActivate(Sender: TObject);
var
  DBName : String;
begin
  DBName:=formMain.queryAlbum.DatabaseName;

  tableAlbum.Active:=False;
  tableAlbum.DatabaseName:=DBName;
  tableAlbum.Active:=True;
//  queryAlbum.Close;
//  queryAlbum.Open;

  tableKeyword.Active:=False;
  tableKeyword.DatabaseName:=DBName;
  tableKeyword.Active:=True;

  LoadKeywordToListBox(listboxOldKeyword);
  LoadKeywordToListBox(listboxRemoveKeyword);
end;

procedure TformKeywordEdit.menuFileAppendClick(Sender: TObject);
begin
  ShowMessage('Not functional.  Sorry.');
end;

procedure TformKeywordEdit.menuFileRemoveClick(Sender: TObject);
begin
  ShowMessage('Not functional.  Sorry.');
end;

procedure TformKeywordEdit.menuFileReplaceClick(Sender: TObject);
var
  I                   : Longint;
  Keywords            : String;
  NewKeyword          : String;
  NoOfRecords         : Longint;
  OldKeyword          : String;
  OldKeywordLength    : Integer;
  Position  : Integer;
begin
  if listboxOldKeyword.ItemIndex=-1 then begin
    MessageDlg('Old Keyword is not selected.',mtWarning,[mbOK],0);
    exit;
  end;
  if editNewKeyword.Text='' then begin
    MessageDlg('New Keyword is empty.',mtWarning,[mbOK],0);
    exit;
  end;

//  NoOfRecords:=queryAlbum.RecordCount;
  NoOfRecords:=tableAlbum.RecordCount;
//showmessage('NoOfRecords='+inttostr(NoOfRecords));
  if NoOfRecords=0 then begin
    MessageDlg('No record.',mtWarning,[mbOK],0);
    exit;
  end;


  OldKeyword:=listboxOldKeyword.Items[listboxOldKeyword.ItemIndex];
  OldKeywordLength:=Length(OldKeyword);
  NewKeyword:=editNewKeyword.Text;

  progressbarProcessing.Min:=0;
  progressbarProcessing.Max:=NoOfRecords;
  progressbarProcessing.Position:=0;

  EnableControls(False);
  tableAlbum.First;
  I:=0;
  while not(tableAlbum.Eof) do begin
    Keywords:=tableAlbum.FieldByName('KEYWORD').AsString;
    Position:=pos(OldKeyword, Keywords);
    if Position>0 then begin
      Delete(Keywords,Position,OldKeywordLength);
      Insert(NewKeyword,Keywords,Position);
      tableAlbum.Edit;
      tableAlbum.FieldByName('KEYWORD').AsString:=Keywords;
      tableAlbum.Post;
    end;
    tableAlbum.Next;
    inc(I);
    progressbarProcessing.Position:=I;
  end;
  progressbarProcessing.Position:=0;

  formMain.queryAlbum.Close;
  formMain.queryAlbum.Open;
  formMain.dbgridAlbum.Refresh;

  EnableControls(True);


end;

procedure TformKeywordEdit.menuHelpInEnglishClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordedit.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformKeywordEdit.menuHelpInJapaneseClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordedit-j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;



end.
