(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 * ****************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit KeywordList;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, Grids, DBGrids, Db, DBTables, ExtCtrls, ComCtrls, StdCtrls,
  Buttons, DBCtrls;

type
  TformKeywordList = class(TForm)
    datasourceKeyword           : TDataSource;
    dbgridKeyword               : TDBGrid;
    menuFile                    : TMenuItem;
    menuFileClose               : TMenuItem;
    menuFileUpdateKeyword       : TMenuItem;
    menuHelp                    : TMenuItem;
    menuHelpInEnglish           : TMenuItem;
    menuHelpInJapanese          : TMenuItem;
    menuMain                    : TMainMenu;
    menuOption                  : TMenuItem;
    menuOptionOrderByCount      : TMenuItem;
    menuOptionOrderByKeyword    : TMenuItem;
    panelBottom                 : TPanel;
    statusbarBottom             : TStatusBar;
    panelButtons: TPanel;
    bitbtnClose: TBitBtn;
    dbnavigatorKeyword: TDBNavigator;
    queryKeyword: TQuery;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure menuFileCloseClick(Sender: TObject);
    procedure menuFileUpdateKeywordClick(Sender: TObject);
    procedure menuHelpInEnglishClick(Sender: TObject);
    procedure menuHelpInJapaneseClick(Sender: TObject);
    procedure menuOptionOrderByCountClick(Sender: TObject);
    procedure menuOptionOrderByKeywordClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure queryKeywordAfterEdit(DataSet: TDataSet);
    procedure queryKeywordPostError(DataSet: TDataSet; E: EDatabaseError;
      var Action: TDataAction);
    procedure queryKeywordBeforeEdit(DataSet: TDataSet);
    procedure queryKeywordBeforePost(DataSet: TDataSet);
  private
    procedure LoadKeywordToListBox;
  public
  end;

var
  formKeywordList: TformKeywordList;

implementation

{$R *.DFM}
uses UpdateKey, main,ShellAPI;

procedure TformKeywordList.LoadKeywordToListBox;
var
  DBName : String;
begin
  DBName:=formMain.queryAlbum.DatabaseName;
  queryKeyword.Active:=False;
  queryKeyword.DatabaseName:=DBName;
  queryKeyword.Active:=True;
  queryKeyword.Close;
  queryKeyword.Open;
end;


procedure TformKeywordList.FormShow(Sender: TObject);
begin
  LoadKeywordToListBox;
end;

procedure TformKeywordList.menuFileCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TformKeywordList.FormCreate(Sender: TObject);
begin
  menuOptionOrderByKeyword.Checked:=True;
  menuOptionOrderByCount.Checked:=False;
end;

procedure TformKeywordList.menuOptionOrderByKeywordClick(Sender: TObject);
begin
  menuOptionOrderByKeyword.Checked:=True;
  menuOptionOrderByCount.Checked:=False;
  queryKeyword.Active:=False;
  queryKeyword.SQL.Clear;
  queryKeyword.SQL.Add('select * from KEYWORD.DB;');
  queryKeyword.Active:=True;
  queryKeyword.Close;
  queryKeyword.Open;
end;

procedure TformKeywordList.menuOptionOrderByCountClick(Sender: TObject);
begin
  menuOptionOrderByKeyword.Checked:=False;
  menuOptionOrderByCount.Checked:=True;
  queryKeyword.Active:=False;
  queryKeyword.SQL.Clear;
  queryKeyword.SQL.Add('select KEYWORD,KEYWORD.DB."COUNT" from KEYWORD.DB order by KEYWORD.DB."COUNT" desc,KEYWORD;');
  queryKeyword.Active:=True;
  queryKeyword.Close;
  queryKeyword.Open;
end;

procedure TformKeywordList.menuFileUpdateKeywordClick(Sender: TObject);
begin
  formUpdateKeyword.ShowModal;
  LoadKeywordToListBox;
end;

procedure TformKeywordList.menuHelpInEnglishClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordlist.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformKeywordList.menuHelpInJapaneseClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordlist-j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformKeywordList.FormResize(Sender: TObject);
var
  Left : Integer;
begin
  Left:=panelBottom.Width div 2;
  Left:=Left-(panelButtons.Width div 2);
  if Left<0 then Left:=0;
  panelButtons.Left:=Left;
end;

procedure TformKeywordList.queryKeywordAfterEdit(DataSet: TDataSet);
begin
  queryKeyword.FieldByName('COUNT').AsInteger:=0;
end;

procedure TformKeywordList.queryKeywordPostError(DataSet: TDataSet;
  E: EDatabaseError; var Action: TDataAction);
begin
  MessageDlg('Could not post data.  Check the value of the "Count" field.  It must have the value.',mtInformation,[mbOK],0);
end;

procedure TformKeywordList.queryKeywordBeforeEdit(DataSet: TDataSet);
begin
  queryKeyword.FieldByName('COUNT').AsInteger:=0;
end;

procedure TformKeywordList.queryKeywordBeforePost(DataSet: TDataSet);
begin
  if queryKeyword.FieldByName('COUNT').IsNull then queryKeyword.FieldByName('COUNT').AsInteger:=0;
end;

end.
