(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit UpdateKey;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, StdCtrls, Buttons, Menus, Db, DBTables, Grids, DBGrids,
  ExtCtrls,Global;

type
  TformUpdateKeyword = class(TForm)
    bitbtnOK                : TBitBtn;
    labelPhase1             : TLabel;
    labelPhase2             : TLabel;
    labelPhase3             : TLabel;
    progressbarKeywordCount : TProgressBar;
    progressbarRecord       : TProgressBar;
    progressbarUnique       : TProgressBar;
    queryAlbum              : TQuery;
    queryWork               : TQuery;
    tableKeyword            : TTable;
    tableWork               : TTable;
    procedure bitbtnOKClick(Sender: TObject);
    procedure UpdateKeyword(Sender: TObject);
  private
    procedure CreateWorkTable(WorkTableName:String);
  public
  end;

var
  formUpdateKeyword: TformUpdateKeyword;

implementation

uses ShellAPI,main;

{$R *.DFM}

procedure TformUpdateKeyword.CreateWorkTable(WorkTableName:String);
begin
  tableWork.Active:=False;
  tableWork.DatabaseName:=formMain.queryAlbum.DatabaseName;
  tableWork.TableName:=WorkTableName;
  tableWork.TableType:=ttDefault;

  tableWork.FieldDefs.Clear;
  tableWork.FieldDefs.Add('KEYWORD', ftString, 32, True);
  tableWork.IndexDefs.Clear;
  tableWork.CreateTable;
end;



procedure TformUpdateKeyword.UpdateKeyword(Sender: TObject);
const
  WorkTableName = 'work.db';
var
  DBName      : String;
  I           : Longint;
  KeywordStr  : String;
  KeywordCount : Longint;
  NoOfRecords : Longint;
  OneWord     : String;
begin
    Application.ProcessMessages;

  bitbtnOK.Enabled:=False;
  progressbarRecord.Position:=0;
  progressbarUnique.Position:=0;
  progressbarKeywordCount.Position:=0;

  CreateWorkTable(WorkTableName);
  tableWork.Active:=True;

  DBName:=formMain.queryAlbum.DatabaseName;

  queryAlbum.Active:=False;
  queryAlbum.DatabaseName:=DBName;
  queryAlbum.Active:=True;
  queryAlbum.Close;
  queryAlbum.Open;


  NoOfRecords:=queryAlbum.RecordCount;
  progressbarRecord.Min:=1;
  progressbarRecord.Max:=NoOfRecords;
  queryAlbum.First;
  for I:=1 to NoOfRecords do begin
    KeywordStr:=queryAlbum.FieldByName('KEYWORD').AsString;
    while KeywordStr<>'' do begin
      OneWord:=ShiftWord(KeyWordStr,',');
      tableWork.Append;
      tableWork.FieldByName('KEYWORD').AsString:=OneWord;
      tableWork.Post;
    end;
    progressbarRecord.Position:=I;
    progressbarRecord.Update;
    queryAlbum.Next;
    Application.ProcessMessages;
  end;


  (* Copyring unique keyword *)
  queryWork.Active:=False;
  queryWork.DatabaseName:=DBName;
  queryWork.SQL.Clear;
  queryWork.SQL.Add('select distinct KEYWORD from "WORK.DB";');
  queryWork.Active:=True;
  queryWork.Close;
  queryWork.Open;

  tableKeyword.Active:=False;
  tableKeyword.DatabaseName:=DBName;
  tableKeyword.EmptyTable;
  tableKeyword.Active:=True;

  NoOfRecords:=queryWork.RecordCount;
  progressbarUnique.Min:=1;
  progressbarUnique.Max:=NoOfRecords;
  queryWork.First;
  for I:=1 to NoOfRecords do begin
    OneWord:=queryWork.FieldByName('KEYWORD').AsString;
    tableKeyword.Append;
    tableKeyword.FieldByName('KEYWORD').AsString:=OneWord;
    tableKeyword.FieldByName('COUNT').AsInteger:=0;
    tableKeyword.Post;
    queryWork.Next;
    progressbarUnique.Position:=I;
    progressbarUnique.Update;
    Application.ProcessMessages;
  end;

  (* Counting each keyword in the records *)
  NoOfRecords:=tableKeyword.RecordCount;
  progressbarKeywordCount.Min:=1;
  progressbarKeywordCount.Max:=NoOfRecords;
  tableKeyword.First;
  for I:=1 to NoOfRecords do begin
    OneWord:=tableKeyword.FieldByName('KEYWORD').AsString;
    queryWork.Active:=False;
    queryWork.SQL.Clear;
    queryWork.SQL.Add('select KEYWORD from "WORK.DB" where KEYWORD="'+OneWord+'";');
    queryWork.Active:=True;
    queryWork.Close;
    queryWork.Open;
    KeywordCount:=queryWork.RecordCount;
    tableKeyword.Edit;
    tableKeyword.FieldByName('COUNT').AsInteger:=KeywordCount;
    tableKeyword.Post;
    tableKeyword.Next;
    progressbarKeywordCount.Position:=I;
    progressbarKeywordCount.Update;
    Application.ProcessMessages;
  end;
  tableWork.Active:=False;
  tableWork.DeleteTable; (* Deletes work table *)
  bitbtnOK.Enabled:=True;
end;



procedure TformUpdateKeyword.bitbtnOKClick(Sender: TObject);
begin
  Close;
end;

end.
