(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit easy;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, Db, DBTables, DBCtrls, checklst, ExtCtrls, ComCtrls,
  Menus,ShellAPI;

type
  TformEasyFilter = class(TForm)
    barStatus                   : TStatusBar;
    bitbtnClear                 : TBitBtn;
    bitbtnClose                 : TBitBtn;
    bitbtnExecute               : TBitBtn;
    checkboxBoolNOT             : TCheckBox;
    checkboxNot1                : TCheckBox;
    checkboxNot2                : TCheckBox;
    checkboxNot3                : TCheckBox;
    checklistboxKeyWords        : TCheckListBox;
    comboboxKeyWord1            : TComboBox;
    comboboxKeyWord2            : TComboBox;
    comboboxKeyWord3            : TComboBox;
    editName                    : TEdit;
    editPrefix                  : TEdit;
    groupboxKeyWord             : TGroupBox;
    labelName                   : TLabel;
    labelPrefix                 : TLabel;
    menuEdit                    : TMenuItem;
    menuEditClear               : TMenuItem;
    menuFile                    : TMenuItem;
    menuFileClose               : TMenuItem;
    menuFileExecute             : TMenuItem;
    menuHelp                    : TMenuItem;
    menuHelpInEnglish           : TMenuItem;
    menuHelpInJapanese          : TMenuItem;
    menuMain                    : TMainMenu;
    menuOption                  : TMenuItem;
    menuOptionBoolAND           : TMenuItem;
    menuOptionBoolNOT           : TMenuItem;
    menuOptionBoolOR            : TMenuItem;
    panelBottom                 : TPanel;
    panelButtons                : TPanel;
    panelKeyWordLeft            : TPanel;
    panelTop                    : TPanel;
    radiogroupBoolAmongItems    : TRadioGroup;
    tableKeyword                : TTable;
    procedure bitbtnClearClick(Sender: TObject);
    procedure checkboxBoolNOTClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure menuEditClearClick(Sender: TObject);
    procedure menuFileCloseClick(Sender: TObject);
    procedure menuFileExecuteClick(Sender: TObject);
    procedure menuHelpInEnglishClick(Sender: TObject);
    procedure menuHelpInJapaneseClick(Sender: TObject);
    procedure menuOptionBoolANDClick(Sender: TObject);
    procedure menuOptionBoolNOTClick(Sender: TObject);
    procedure menuOptionBoolORClick(Sender: TObject);
    procedure radiogroupBoolAmongItemsClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    procedure LoadKeyWordToListBox;
  public
    procedure ResetConditions(Sender: TObject);
  end;

var
  formEasyFilter: TformEasyFilter;

implementation

uses main, Global,Expert;

{$R *.DFM}

procedure TformEasyFilter.ResetConditions(Sender:TObject);
var
  I         : Integer;
  NoOfItems : Integer;
begin
  editPrefix.Text:='';
  editName.Text:='';
  checkboxNot1.Checked:=False;
  checkboxNot2.Checked:=False;
  checkboxNot3.Checked:=False;
  comboboxKeyWord1.Text:='';
  comboboxKeyWord2.Text:='';
  comboboxKeyWord3.Text:='';
  NoOfItems:=checklistboxKeyWords.Items.Count;
  if NoOfItems>0 then begin
    for I:=0 to NoOfItems-1 do begin
      checklistboxKeyWords.Checked[I]:=False;
    end;
    checklistboxKeyWords.Refresh;
  end;
  menuOptionBoolAND.Checked:=True;
  menuOptionBoolOR.Checked:=False;
  radiogroupBoolAmongItems.ItemIndex:=0;
  menuOptionBoolNOT.Checked:=False;
  checkboxBoolNOT.Checked:=False;
end;


procedure TformEasyFilter.menuFileCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TformEasyFilter.menuFileExecuteClick(Sender: TObject);
var
  AndOr      : String;
  Conditions : String;
  I          : Integer;
  NoOfItems  : Integer;
  Str        : String;
begin
  (* Common statements *)
  formMain.queryAlbum.SQL.Clear;
  formMain.queryAlbum.SQL.Add('SELECT * FROM PHOTODB.DB ');
  Conditions:='';


  if menuOptionBoolAND.Checked=True then AndOr:=' AND '
  else AndOr:=' OR ';

  (* Prefix *)
  if editPrefix.Text<>'' then begin
    Conditions:='PREFIX LIKE "'+editPrefix.Text+'%"';
  end;

  (* Name *)
  Str:=editName.Text;
  if Str<> '' then begin
    Str:='NAME LIKE "'+Str+'%"';
    if Conditions='' then Conditions:=Str
    else Conditions:=Conditions+AndOr+Str;
  end;

  (* Key word 1 *)
  Str:=comboboxKeyWord1.Text;
  if Str<> '' then begin
    Str:='KEYWORD LIKE "%'+Str+'%"';
    if checkboxNot1.Checked then Str:='NOT('+Str+')';
    if Conditions='' then Conditions:=Str
    else Conditions:=Conditions+AndOr+Str;
  end;

  (* Key word 2 *)
  Str:=comboboxKeyWord2.Text;
  if Str<> '' then begin
    Str:='KEYWORD LIKE "%'+Str+'%"';
    if checkboxNot2.Checked then Str:='NOT('+Str+')';
    if Conditions='' then Conditions:=Str
    else Conditions:=Conditions+AndOr+Str;
  end;

  (* Key word 3 *)
  Str:=comboboxKeyWord3.Text;
  if Str<> '' then begin
    Str:='KEYWORD LIKE "%'+Str+'%"';
    if checkboxNot3.Checked then Str:='NOT('+Str+')';
    if Conditions='' then Conditions:=Str
    else Conditions:=Conditions+AndOr+Str;
  end;

  (* Key words *)
  //if checklistboxKeyWords.SelCount>0 then begin
    NoOfItems:=checklistboxKeyWords.Items.Count;
    if NoOfItems>0 then begin
      for I:=0 to NoOfItems-1 do begin
        if checklistboxKeyWords.Checked[I]=True then begin
          Str:='KEYWORD LIKE "%'+checklistboxKeyWords.Items[I]+'%"';
          if Conditions='' then Conditions:=Str
          else Conditions:=Conditions+AndOr+Str;
        end;
      end;
    end;
  //end;


  (* NOT for all items *)
  if Conditions<>'' then begin
    if menuOptionBoolNOT.Checked=True then Conditions:='NOT('+Conditions+')';
  //messagedlg(Conditions,mtInformation,[mbOK],0);
    formMain.queryAlbum.SQL.Add('WHERE '+Conditions);
  end;




  (* Common statements *)
  formMain.queryAlbum.SQL.Add(';');
  formMain.queryAlbum.Close;
  formMain.queryAlbum.Open;
  formMain.DisplayRecordCount;
  //formSQL.memoConditions.Lines:=formMain.queryAlbum.SQL;
  formExpertFilter.memoSQL.Clear;
  formExpertFilter.memoSQL.Lines.Add(Conditions);
end;

procedure TformEasyFilter.LoadKeyWordToListBox;
var
  I           : Integer;
  KeyWord     : String;
  NoOfRecords : Integer;
begin
  tableKeyWord.Active:=False;
  tableKeyWord.DatabaseName:=formMain.queryAlbum.DatabaseName;
  tableKeyWord.Active:=True;
  tableKeyWord.Last;
  NoOfRecords:=tableKeyWord.RecordCount;
  if NoOfRecords=0 then Exit;
  tableKeyWord.First;

  comboboxKeyWord1.Items.Clear;
  comboboxKeyWord2.Items.Clear;
  comboboxKeyWord3.Items.Clear;
  checklistboxKeyWords.Clear;
  for I:=0 to NoOfRecords-1 do begin
    KeyWord:=tableKeyWord.FieldByName('KEYWORD').AsString;
    comboboxKeyWord1.Items.Add(KeyWord);
    comboboxKeyWord2.Items.Add(KeyWord);
    comboboxKeyWord3.Items.Add(KeyWord);
    checklistboxKeyWords.Items.Add(KeyWord);
    tableKeyWord.Next;
  end;
end;


procedure TformEasyFilter.FormResize(Sender: TObject);
var
  Left : Integer;
begin
  Left:=panelBottom.Width div 2;
  Left:=Left-(panelButtons.Width div 2);
  if Left<0 then Left:=0;
  panelButtons.Left:=Left;
end;

procedure TformEasyFilter.menuEditClearClick(Sender: TObject);
begin
  ResetConditions(Sender);
end;

procedure TformEasyFilter.bitbtnClearClick(Sender: TObject);
begin
  ResetConditions(Sender);
end;


procedure TformEasyFilter.menuOptionBoolANDClick(Sender: TObject);
begin
  menuOptionBoolAND.Checked:=True;
  menuOptionBoolOR.Checked:=False;
  radiogroupBoolAmongItems.ItemIndex:=0;
end;

procedure TformEasyFilter.menuOptionBoolORClick(Sender: TObject);
begin
  menuOptionBoolAnd.Checked:=False;
  menuOptionBoolOR.Checked:=True;
  radiogroupBoolAmongItems.ItemIndex:=1;
end;

procedure TformEasyFilter.menuOptionBoolNOTClick(Sender: TObject);
begin
  menuOptionBoolNOT.Checked:=not(menuOptionBoolNOT.Checked);
  checkboxBoolNOT.Checked:=menuOptionBoolNOT.Checked;
end;

procedure TformEasyFilter.radiogroupBoolAmongItemsClick(Sender: TObject);
begin
  if radiogroupBoolAmongItems.ItemIndex=0 then begin
    menuOptionBoolAND.Checked:=True;
    menuOptionBoolOR.Checked:=False;
  end
  else begin
    menuOptionBoolAND.Checked:=False;
    menuOptionBoolOR.Checked:=True;
  end;
end;

procedure TformEasyFilter.checkboxBoolNOTClick(Sender: TObject);
begin
  menuOptionBoolNOT.Checked:=checkboxBoolNOT.Checked;
end;

procedure TformEasyFilter.menuHelpInEnglishClick(Sender: TObject);
const
  FileName = '..\manual\qr-easyfilter.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformEasyFilter.menuHelpInJapaneseClick(Sender: TObject);
const
  FileName = '..\manual\qr-easyfilter-j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformEasyFilter.FormShow(Sender: TObject);
begin
  if formMain.queryAlbum.Active=True then begin
    LoadKeyWordToListBox;
  end;
end;

end.
