(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit expert;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ComCtrls, ExtCtrls, Menus;

type
  TformExpertFilter = class(TForm)
    barStatus       : TStatusBar;
    bitbtnClose     : TBitBtn;
    bitbtnExecute   : TBitBtn;
    bitbtnReset     : TBitBtn;
    labelExample    : TLabel;
    labelSQL        : TLabel;
    memoSQL         : TMemo;
    menuFile        : TMenuItem;
    menuFileClose   : TMenuItem;
    menuFileExecute : TMenuItem;
    menuFileReset   : TMenuItem;
    menuHelp        : TMenuItem;
    menuHelpInEng   : TMenuItem;
    menuHelpInJap   : TMenuItem;
    menuMain        : TMainMenu;
    panelBottom     : TPanel;
    panelButtons    : TPanel;
    panelTop        : TPanel;
    procedure FormResize(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure menuFileCloseClick(Sender: TObject);
    procedure menuFileExecuteClick(Sender: TObject);
    procedure menuFileResetClick(Sender: TObject);
    procedure menuHelpInEngClick(Sender: TObject);
    procedure menuHelpInJapClick(Sender: TObject);
  private
  public
  end;

var
  formExpertFilter: TformExpertFilter;

implementation

uses main, easy,ShellAPI;

{$R *.DFM}

procedure TformExpertFilter.FormShow(Sender: TObject);
var
  I         : Integer;
  NoOfLines : Integer;
begin
  NoOfLines:=formMain.queryAlbum.SQL.Count;
  memoSQL.Lines.Clear;
  for I:=0 to NoOfLines-1 do begin
    memoSQL.Lines.Add(formMain.queryAlbum.SQL.Strings[I]);
  end;
  memoSQL.SetFocus;
end;


procedure TformExpertFilter.FormResize(Sender: TObject);
var
  Left : Integer;
begin
  Left:=panelBottom.Width div 2;
  Left:=Left-(panelButtons.Width div 2);
  if Left<0 then Left:=0;
  panelButtons.Left:=Left;
end;

procedure TformExpertFilter.menuFileExecuteClick(Sender: TObject);
var
  I         : Integer;
  NoOfLines : Integer;
begin
  NoOfLines:=memoSQL.Lines.Count;
  if NoOfLines=0 then begin
    MessageDlg('No SQL statement.',mtWarning,[mbOK],0);
    exit;
  end;
  formMain.queryAlbum.SQL.Clear;
  for I:=0 to NoOfLInes-1 do begin
    formMain.queryAlbum.SQL.Add(memoSQL.Lines[I]);
  end;
  formMain.queryAlbum.Close;
  try
    formMain.queryAlbum.Open;
  except
    formMain.imageViewArea.Visible:=False;
    MessageDlg('Wrong SQL statement.',mtWarning,[mbOK],0);
  end;
  formMain.DisplayRecordCount;
  formEasyFilter.ResetConditions(Sender);
end;

procedure TformExpertFilter.menuFileCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TformExpertFilter.menuFileResetClick(Sender: TObject);
begin
  memoSQL.Lines.Clear;
  memoSQL.Lines.Add('select * from PHOTODB.DB;');
  memoSQL.Refresh;
//  formMain.queryAlbum.SQL.Clear;
//  formMain.queryAlbum.SQL.Add('select * from PHOTODB.DB;');
//  formMain.queryAlbum.Active:=True;
end;

procedure TformExpertFilter.menuHelpInEngClick(Sender: TObject);
(* ****************************************************************************
 * Opens user help written in English.
 * The program uses HTML files for help.  Users need a web browser such as
 * Netscape Navigator or Internet Explorer.
 * ****************************************************************************
 *)
const
  FileName = '..\manual\qr-expertfilter.html';
var
  Ans       : word;
begin
  Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
  DisplayResult(Ans, FileName);
end;

procedure TformExpertFilter.menuHelpInJapClick(Sender: TObject);
(* ****************************************************************************
 * Opens user help written in English.
 * The program uses HTML files for help.  Users need a web browser such as
 * Netscape Navigator or Internet Explorer.
 * ****************************************************************************
 *)
const
  FileName = '..\manual\qr-expertfilter-j.html';
var
  Ans       : word;
begin
  Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
  DisplayResult(Ans, FileName);
end;

end.
