(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit imgtrans;

interface
uses ExtCtrls,jpeg,Classes,Forms;

procedure ImageTransfer(var ImageMast:TImage;var ImageDest:TImage;
 var scrollboxViewArea:TScrollBox; Stretch:Boolean);
(* This procedure transfers image from the "ImageMast" to the "ImageDest".
 * "ImageDest" is in "scrollboxViewArea". If "Strech" is true and the target
 * image is larger than the "scrollboxViewArea", the target image will be
 * resized due to put in the "scrollboxViewArea". This procedure holds the
 * aspect ratio of the target image.
 *)

implementation

procedure StretchSize(X1,Y1,X2,Y2:Integer; var X3,Y3:Integer);
(* X1,Y1: Master inamge size
 * X2,Y2: View area size
 * X3,Y3: Output image size
 *)
var
  AspectRatio : single;
  TmpX,TmpY : single;
begin
  if (X1<=X2)and(Y1<=Y2) then begin
    X3:=X1;
    Y3:=Y1;
    exit;
  end;
  AspectRatio:=X1/Y1;
  TmpX:=X2;
  TmpY:=TmpX/AspectRatio;
  if TmpY>Y2 then begin
    TmpY:=Y2;
    TmpX:=TmpY*AspectRatio;
  end;
  X3:=Trunc(TmpX);
  Y3:=Trunc(TmpY);
end;


procedure ImageTransfer(var ImageMast:TImage;var ImageDest:TImage;
 var scrollboxViewArea:TScrollBox; Stretch:Boolean);
var
  IsJPEG  : Boolean;
  OffsetX : Integer;
  OffsetY : Integer;
  X1,Y1   : Integer;
  X2,Y2   : Integer;
  X3,Y3   : Integer;
begin
  IsJPEG:=ImageMast.Picture.Graphic is TJPEGImage;
  if not(IsJPEG) then exit;
  X1:=ImageMast.Picture.Graphic.Width;
  Y1:=ImageMast.Picture.Graphic.Height;
  if Stretch then begin (* Stretch *)
    X2:=scrollboxViewArea.Width;
    Y2:=scrollboxViewArea.Height;
    StretchSize(X1,Y1,X2,Y2,X3,Y3);
    OffsetX:=(X2-X3) div 2;
    if OffsetX+X3>X2 then OffsetX:=X2-X3;
    OffsetY:=(Y2-Y3) div 2;
    if OffsetY+Y3>Y2 then OffsetY:=Y2-Y3;
    ImageDest.Visible:=False;
    ImageDest.Picture.Bitmap.Width:=X3;
    ImageDest.Picture.Bitmap.Height:=Y3;
    ImageDest.Top:=OffsetY;
    ImageDest.Left:=OffsetX;
    ImageDest.Canvas.StretchDraw(Rect(0,0,X3,Y3),ImageMast.Picture.Graphic);
    (* Actually, it must be Rect(0,0,X3-1,Y3-1). However, it does not run
     * well if you do so.
     *)
    ImageDest.Visible:=True;
  end
  else begin (* Full Size *)
    ImageDest.Visible:=False;
    ImageDest.Top:=0;
    ImageDest.Left:=0;
    ImageDest.Picture.Bitmap.Width:=X1;
    ImageDest.Picture.Bitmap.Height:=Y1;
    ImageDest.Canvas.Draw(0,0,ImageMast.Picture.Graphic);
    ImageDest.Visible:=True;
  end;
end;

end.
 