(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 * ****************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit keywordassist;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, StdCtrls, checklst, ExtCtrls, ComCtrls, Db, DBTables, Buttons;

type
  TformKeywordAssist = class(TForm)
    StatusBar1: TStatusBar;
    Panel1: TPanel;
    checklistboxKeywords: TCheckListBox;
    menuMain: TMainMenu;
    menuFile: TMenuItem;
    menuFileUpdateKeyword: TMenuItem;
    menuFileClose: TMenuItem;
    menuHelp: TMenuItem;
    menuHelpInEnglish: TMenuItem;
    menuHelpInJapanese: TMenuItem;
    tableKeyWord: TTable;
    bitbtnEnter: TBitBtn;
    bitbtnClose: TBitBtn;
    procedure LoadKeywordToListBox;
    procedure menuFileCloseClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure bitbtnEnterClick(Sender: TObject);
    procedure menuHelpInEnglishClick(Sender: TObject);
    procedure menuHelpInJapaneseClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
  private
  public
  end;

var
  formKeywordAssist: TformKeywordAssist;
implementation

uses main,RegUtl,Global,ShellAPI;

{$R *.DFM}

procedure TformKeywordAssist.LoadKeywordToListBox;
var
  I           : Longint;
  KeyWord     : String;
  KeyWords    : String;
  NewIndex    : Integer;
  NoOfRecords : Longint;
begin
  tableKeyWord.Active:=False;
  tableKeyWord.DatabaseName:=formMain.queryAlbum.DatabaseName;
  tableKeyWord.Active:=True;
  tableKeyWord.Last;
  NoOfRecords:=tableKeyWord.RecordCount;
  if NoOfRecords>0 then begin
    tableKeyWord.First;
    checklistboxKeyWords.Clear;
    while not(tableKeyWord.Eof) do begin
    //for I:=0 to NoOfRecords-1 do begin
      KeyWord:=tableKeyWord.FieldByName('KEYWORD').AsString;
      checklistboxKeyWords.Items.Add(KeyWord);
      tableKeyWord.Next;
    end;
  end;
  KeyWords:=formMain.queryAlbum.FieldByName('KEYWORD').AsString;
//showmessage('Keywords='+KeyWords);
  while KeyWords<>'' do begin
    KeyWord:=ShiftWord(KeyWords,',');
    I:=checklistboxKeyWords.Items.IndexOf(KeyWord);
    if I>=0 then checklistboxKeyWords.Checked[I]:=True
    else begin
      NewIndex:=checklistboxKeyWords.Items.Count;
      checklistboxKeyWords.Items.Add(KeyWord);
      checklistboxKeyWords.Checked[NewIndex]:=True;
    end;
  end;
  checklistboxKeyWords.Refresh;
//checklistboxKeyWords.Checked[I]
//checklistboxKeyWords.Items.Add(KeyWord);
//checklistboxKeyWords.Items[I]
// checklistboxKeyWords.Items.IndexOf('string')

end;


procedure TformKeywordAssist.menuFileCloseClick(Sender: TObject);
begin
  Release;
end;

procedure TformKeywordAssist.FormShow(Sender: TObject);
begin
  LoadKeyWordToListBox;
end;

procedure TformKeywordAssist.FormCreate(Sender: TObject);
begin
  if ExistKey(BaseKeyName+'\'+formKeywordAssist.Name) then begin
    RestoreFormStatus(formKeywordAssist,Global.BaseKeyName);
    //RestoreOptionStatus;
  end
  else begin
    Width:=240;
    Height:=280;
    Position:=poScreenCenter;
  end;
end;

procedure TformKeywordAssist.FormDestroy(Sender: TObject);
begin
  if ExistKey(Global.BaseKeyName) then begin
    StoreFormStatus(formKeywordAssist,Global.BaseKeyName);
    //StoreOptionStatus;
  end;
end;

procedure TformKeywordAssist.FormResize(Sender: TObject);
var
  Center : Integer;
  Left   : Integer;
begin
  Center:=formKeywordAssist.Width div 2;

  Left:=Center-(bitbtnEnter.Width div 2);
  if Left<0 then Left:=0;
  bitbtnEnter.Left:=Left;

  Left:=Center-(bitbtnClose.Width div 2);
  if Left<0 then Left:=0;
  bitbtnClose.Left:=Left;
end;

procedure TformKeywordAssist.bitbtnEnterClick(Sender: TObject);
var
  I         : Integer;
  KeyWord   : String;
  KeyWords  : String;
  NoOfItems : Integer;
begin
  KeyWords:='';
  NoOfItems:=checklistboxKeyWords.Items.Count;
  for I:=0 to NoOfItems-1 do begin
    if checklistboxKeyWords.Checked[I]=True then begin
      KeyWord:=checklistboxKeyWords.Items[I];
      if KeyWords='' then KeyWords:=KeyWord
      else KeyWords:=KeyWords+','+ KeyWord;
    end;
  end;
  formMain.queryAlbum.Edit;
  formMain.queryAlbum.FieldByName('KEYWORD').AsString:=KeyWords;
  formMain.queryAlbum.Post;
end;

procedure TformKeywordAssist.menuHelpInEnglishClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordassist.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformKeywordAssist.menuHelpInJapaneseClick(Sender: TObject);
const
  FileName = '..\manual\qr-keywordassist-j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;

procedure TformKeywordAssist.FormActivate(Sender: TObject);
begin
  LoadKeyWordToListBox;
end;

end.
