(* ****************************************************************************
 *                    Fumio Kawamata's Quick Recall
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit selector;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, jpeg, ExtCtrls, FileCtrl, ComCtrls, Menus, printers,
  Buttons,Db,ImgTrans, DBTables, Grids, DBGrids, checklst;

type
  TformSelector = class(TForm)
    checkboxRemoveAfterInport   : TCheckBox;
    comboboxDrive               : TDriveComboBox;
    dialogOpen                  : TOpenDialog;
    editKeyWord                 : TEdit;
    editPrefix                  : TEdit;
    imageTmp                    : TImage;
    imageViewArea               : TImage;
    labelKeyword                : TLabel;
    labelPrefix                 : TLabel;
    listboxDir                  : TDirectoryListBox;
    listboxFile                 : TFileListBox;
    menuFile                    : TMenuItem;
    menuFileCancelInport        : TMenuItem;
    menuFileExit                : TMenuItem;
    menuFileInport              : TMenuItem;
    menuFileOpen                : TMenuItem;
    menuFileSelectAll           : TMenuItem;
    menuHelp                    : TMenuItem;
    menuHelpInEng               : TMenuItem;
    menuHelpInJap               : TMenuItem;
    menuMain                    : TMainMenu;
    menuOption                  : TMenuItem;
    menuOptionAutoScale         : TMenuItem;
    menuOptionLayout            : TMenuItem;
    menuOptionRemoveAfterInport : TMenuItem;
    panelCommand                : TPanel;
    panelStatusBar              : TStatusBar;
    panelTop                    : TPanel;
    progressbarInport           : TProgressBar;
    queryAlbum                  : TQuery;
    radiogroupScale             : TRadioGroup;
    scrollboxViewArea           : TScrollBox;
    checklistboxKeyWords: TCheckListBox;
    tableKeyWord: TTable;
    Panel1: TPanel;
    bitbtnRefresh: TBitBtn;
    menuEdit: TMenuItem;
    menuEditRefreshList: TMenuItem;
    bitbtnAppend: TBitBtn;
    bitbtnCancel: TBitBtn;
    bitbtnClose: TBitBtn;
    procedure bitbtnCancelClick(Sender: TObject);
    procedure checkboxRemoveAfterInportClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure imageTmpProgress(Sender: TObject; Stage: TProgressStage; PercentDone: Byte; RedrawNow: Boolean; const R: TRect; const Msg: String);
    procedure listboxFileDblClick(Sender: TObject);
    procedure menuFileCancelInportClick(Sender: TObject);
    procedure menuFileExitClick(Sender: TObject);
    procedure menuFileInportClick(Sender: TObject);
    procedure menuFileOpenClick(Sender: TObject);
    procedure menuFileSelectAllClick(Sender: TObject);
    procedure menuHelpInEngClick(Sender: TObject);
    procedure menuHelpInJapClick(Sender: TObject);
    procedure menuOptionAutoScaleClick(Sender: TObject);
    procedure menuOptionLayoutClick(Sender: TObject);
    procedure menuOptionRemoveAfterInportClick(Sender: TObject);
    procedure ProgressUpdate(Sender: TObject; Stage: TProgressStage; PercentDone: Byte; RedrawNow: Boolean; const R: TRect; const Msg: string);
    procedure radiogroupScaleClick(Sender: TObject);
    procedure LoadKeywordToListBox;
    procedure FormShow(Sender: TObject);
    procedure menuEditRefreshListClick(Sender: TObject);
  private
    function  AppendData(FullPath,Prefix,Keyword:String):Boolean;
    procedure DisplayImageBySerial(Serial:Longint);
    procedure DuplicateCheck(FileName:string; var InDuplicate:Boolean; var Serial:Longint);
    procedure ResetQuery;
    procedure RestoreOptionStatus;
    procedure SetControlStatus(Status:Integer);
    procedure StoreOptionStatus;
  public
    function OpenFile(Filename: string):word;
  end;

var
  formSelector: TformSelector;

implementation

uses Registry, main,ShellAPI,RegUtl,Global, easy;

{$R *.DFM}
var
  CancelIt : Boolean;


procedure TformSelector.LoadKeywordToListBox;
var
  I           : Longint;
  KeyWord     : String;
  NoOfRecords : Longint;
begin
  tableKeyWord.Active:=False;
  tableKeyWord.DatabaseName:=formMain.queryAlbum.DatabaseName;
  tableKeyWord.Active:=True;
  tableKeyWord.Last;
  NoOfRecords:=tableKeyWord.RecordCount;
  if NoOfRecords=0 then Exit;
  tableKeyWord.First;
  checklistboxKeyWords.Clear;
  for I:=0 to NoOfRecords-1 do begin
    KeyWord:=tableKeyWord.FieldByName('KEYWORD').AsString;
    checklistboxKeyWords.Items.Add(KeyWord);
    tableKeyWord.Next;
  end;
end;


procedure RemoveFile(FullPath:String);
begin
  if DeleteFile(FullPath)=True then
    MessageDlg('Removed the file "'+FullPath+'".',mtInformation,[mbOK],0)
  else
    MessageDlg('Could not remove the file "'+FullPath+'".',mtWarning,[mbOK],0);
end;

procedure TformSelector.SetControlStatus(Status:Integer);
begin
  if Status=1 then begin
    (* Enable/Disable controls *)
    bitbtnAppend.Enabled:=False;
    //bitbtnCancel.Visible:=True;
    bitbtnCancel.Enabled:=True;
    bitbtnClose.Enabled:=False;
    radiogroupScale.Enabled:=False;
    checkboxRemoveAfterInport.Enabled:=False;
    menuFileExit.Enabled:=False;
    menuFileInport.Enabled:=False;
    menuFileOpen.Enabled:=False;
    menuFileSelectAll.Enabled:=False;
    menuOption.Enabled:=False;
    menuHelp.Enabled:=False;
    comboboxDrive.Enabled:=False;
    listboxDir.Enabled:=False;
    listboxFile.Enabled:=False;
    editPrefix.Enabled:=False;
    editKeyWord.Enabled:=False;
  end
  else begin
    (* Enable/Disable controls *)
    bitbtnAppend.Enabled:=True;
    bitbtnCancel.Enabled:=False;
    //bitbtnCancel.Visible:=False;
    bitbtnClose.Enabled:=True;
    radiogroupScale.Enabled:=True;
    checkboxRemoveAfterInport.Enabled:=True;
    menuFileExit.Enabled:=True;
    menuFileInport.Enabled:=True;
    menuFileOpen.Enabled:=True;
    menuFileSelectAll.Enabled:=True;
    menuOption.Enabled:=True;
    menuHelp.Enabled:=True;
    comboboxDrive.Enabled:=True;
    listboxDir.Enabled:=True;
    listboxFile.Enabled:=True;
    editPrefix.Enabled:=True;
    editKeyWord.Enabled:=True;
  end;
end;

procedure TformSelector.StoreOptionStatus;
var
  AlignStr   : string;
  Reg : TRegIniFile;
  SubKeyName : string;
begin
  case panelCommand.Align of
    alLeft : AlignStr:='Left';
    alRight : AlignStr:='Right';
  end;
  SubKeyName:=formSelector.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);
  Reg.WriteString(SubKeyName,'Panel_Layout',AlignStr);
  Reg.Free;
end;

procedure TformSelector.RestoreOptionStatus;
var
  AlignStr   : string;
  Reg : TRegIniFile;
  SubKeyName : string;
begin
  SubKeyName:=formSelector.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);
  AlignStr:=Reg.ReadString(SubKeyName,'Panel_Layout','Right');
  if AlignStr='Right'
    then panelCommand.Align:=alRight
    else panelCommand.Align:=alLeft;
  Reg.Free;
end;


procedure TformSelector.DuplicateCheck(FileName:string; var InDuplicate:Boolean; var Serial:Longint);
var
    Count       : Word;
    FileBuff    : PChar;
    FileVar     : file of byte;
    File_Size   : integer;
    ImageBuff   : PChar;
    ImageStream : TBlobStream;
    StreamSize  : integer;
begin
  InDuplicate:=False;
  Count:=queryAlbum.RecordCount;
  if Count=0 then Exit;

  (* Get file size. Load image into the pointer variable. *)
  AssignFile(FileVar,FileName);
  Reset(FileVar);
  File_Size:=FileSize(FileVar);
  Reset(FileVar);
  FileBuff:=AllocMem(File_Size+1);
  BlockRead(FileVar,FileBuff^,File_Size);
  CloseFile(FileVar);

  queryAlbum.First;
  while not(queryAlbum.Eof) and (InDuplicate=False) do begin

    //showmessage(queryAlbum.FieldByName('SERIAL').AsString);

    ImageStream:=TBlobStream.Create(TBlobField
      (queryAlbum.FieldByName('IMAGE')),bmRead);
    StreamSize:=ImageStream.Size;
    Serial:=queryAlbum.FieldByName('SERIAL').AsInteger;
    if File_Size<>StreamSize then begin
      MessageDlg('Serious error.  File size('+IntToStr(File_SIZE)
        +') and stream size('+IntToStr(StreamSize)+') are different.',mtWarning,[mbOK],0);
      ImageStream.Free;
      FreeMem(FileBuff);
      Exit;
    end;
    ImageBuff:=AllocMem(StreamSize+1);
    ImageStream.Read(ImageBuff^,StreamSize);

    InDuplicate:=CompareMem(ImageBuff, FileBuff,StreamSize);


    ImageStream.Free;
    FreeMem(ImageBuff);
    queryAlbum.Next;
  end;
  FreeMem(FileBuff);
end;



procedure TformSelector.DisplayImageBySerial(Serial:Longint);
begin
  formMain.queryAlbum.SQL.Clear;
  formMain.queryAlbum.SQL.Add('SELECT * FROM PHOTODB.DB WHERE SERIAL=');
  formMain.queryAlbum.SQL.Add(IntToStr(Serial));
  formMain.queryAlbum.SQL.Add(';');
  formMain.queryAlbum.Close;
  formMain.queryAlbum.Open;
  formMain.DisplayRecordCount;
  formEasyFilter.ResetConditions(formSelector);
end;




(* ========================================================================= *)
function TformSelector.OpenFile(FileName: string):word;
(* Opens file named FileName variable.
* Returns 1:Detected duplication or 0:Not.
*)
var
  FileVar : file of byte;
  File_Size    : Longint;
  InDuplicate : Boolean;
  Serial       : Longint;
begin
  Result:=0;
  Screen.Cursor := crHourglass;
  try
    imageTmp.Picture.LoadFromFile(FileName);
    (* Display image *)
    radiogroupScale.ItemIndex:=0;
    imgtrans.ImageTransfer(imageTmp,imageViewArea,scrollboxViewArea,True);
    scrollboxViewArea.Refresh;

    (* Query data which occupies same image size. *)
    AssignFile(FileVar, FileName);
    Reset(FileVar);
    File_Size:=FileSize(FileVar);
    CloseFile(FileVar);
    queryAlbum.Active:=False;
    queryAlbum.DatabaseName:=formMain.queryAlbum.DatabaseName;
    queryAlbum.Active:=True;
    queryAlbum.Params[0].AsInteger:=File_Size;
    queryAlbum.Close;
    queryAlbum.Open;

    if queryAlbum.RecordCount>0 then begin
      //showmessage(inttostr(queryAlbum.RecordCount));
      DuplicateCheck(FileName,InDuplicate,Serial);
      if InDuplicate=True then begin
        //bitbtnAppend.Enabled:=False;
        DisplayImageBySerial(Serial);
        MessageDlg('Detected same image in the database.',mtWarning,[mbOK],0);
        Result:=1;
      end;
    end;

  except
    on EInvalidGraphic do
      imageTmp.Picture.Graphic := nil;
  end;
  Screen.Cursor := crArrow;
end;





procedure TformSelector.listboxFileDblClick(Sender: TObject);
begin
  OpenFile(listboxFile.Filename);
end;


procedure TformSelector.FormCreate(Sender: TObject);
begin
  //scrollboxViewArea.Color:=clBlack;
  if ExistKey(Global.BaseKeyName+'\'+formSelector.Name) then begin
    RestoreFormStatus(formSelector,Global.BaseKeyName);
    RestoreOptionStatus;
  end
  else begin
    Width:=640;
    Height:=480;
    Position:=poScreenCenter;
  end;
  radiogroupScale.ItemIndex := 0;
  dialogOpen.Filter := '*.jpg;*.jpeg';
  listboxFile.Mask := '*.jpg;*.jpeg';
  imageViewArea.OnProgress := ProgressUpdate;
  queryAlbum.DatabaseName:=formMain.queryAlbum.DatabaseName;
  editPrefix.Text:='';
end;

procedure TformSelector.ProgressUpdate(Sender: TObject; Stage: TProgressStage;
  PercentDone: Byte; RedrawNow: Boolean; const R: TRect; const Msg: string);
begin
  if Stage = psRunning then
    Caption := Format('%d%%',[PercentDone])
  else
    Caption := 'Form1';
end;


procedure TformSelector.menuFileOpenClick(Sender: TObject);
var
  FullPath : String;
begin
  if dialogOpen.Execute then begin
    FullPath:=dialogOpen.FileName;
    listboxFile.ApplyFilePath(FullPath);
    listboxFile.Selected[0]:=True;
    OpenFile(FullPath);
  end;
end;


procedure TformSelector.menuFileExitClick(Sender: TObject);
begin
  Close;
end;



function TformSelector.AppendData(FullPath,Prefix,Keyword:String):Boolean;
(* Returns True when it is succeeded.
 *)
var
    Ext        : string;
    Name       : string;
    NameAndExt : string;
    ExtPos     : Integer;
begin
  Result:=True;
  NameAndExt:=ExtractFileName(FullPath);
  Ext:=ExtractFileExt(NameAndExt);
  ExtPos:=pos(Ext,NameAndExt);
  if ExtPos>0 then begin (* It must be TRUE allways. *)
    Name:=copy(NameAndExt,1,ExtPos-1);
  end
  else begin
    MessageDlg('No extention.',mtWarning,[mbOK],0);
    exit;
  end;
  if Length(Name)=0 then begin
    MessageDlg('Name is null string.',mtWarning,[mbOK],0);
    exit;
  end;
  Name:=AnsiLowerCase(Name);


  formMain.queryAlbum.Append;
  formMain.queryAlbum.FieldByName('PREFIX').AsString:=Prefix;
  formMain.queryAlbum.FieldByName('NAME').AsString:=Name;
  formMain.queryAlbum.FieldByName('EXT').AsString:='.jpg';
  formMain.queryAlbum.FieldByName('KEYWORD').AsString:=KeyWord;
  TBlobField(formMain.queryAlbum.FieldByName('IMAGE')).LoadFromFile(FullPath);
  formMain.queryAlbum.FieldByName('COUNT').AsInteger:=0;
  formMain.queryAlbum.FieldByName('IMAGE_SIZE').AsInteger
    :=TBlobField(formMain.queryAlbum.FieldByName('IMAGE')).BlobSize;
  formMain.queryAlbum.post;
  formMain.imageTmp.Picture.Graphic
    :=formSelector.imageTmp.Picture.Graphic;
  imgtrans.ImageTransfer(formMain.imageTmp,formMain.imageViewArea,formMain.scrollboxViewArea,True);
end;


procedure TformSelector.ResetQuery;
begin
  formMain.queryAlbum.SQL.Clear;
  formMain.queryAlbum.SQL.Add('SELECT * FROM PHOTODB.DB;');
  formMain.queryAlbum.Close;
  formMain.queryAlbum.Open;
  formMain.DisplayRecordCount;
  formEasyFilter.ResetConditions(formSelector);
end;


procedure TformSelector.menuFileInportClick(Sender: TObject);
var
  Count : Integer;
  I     : Integer;
  FullPath      : string;
  IsJPEGImage   : Boolean;
  Keyword       : String;
  LastName      : string;
  MessStr       : string;
  NameAndExt    : string;
  NoOfItems     : Integer;
  SelectedCount : Integer;
  Prefix        : String;
  ProcessedCount : Integer;
begin
  LastName:='';
  Count:=listboxFile.Items.Count;
  SelectedCount:=0;
  if Count>0 then begin
    for I:=0 to Count-1 do begin
      if listboxFile.Selected[I]=True then inc(SelectedCount);
    end;
  end;
  if SelectedCount=0 then begin
     MessageDlg('File is not selected.  Please select file(s).',mtWarning,[mbOK],0);
     exit;
  end;
(* Warning block. Commented for the running test. 1998/7/19 Fumio Kawamata
  if menuOptionRemoveAfterInport.Checked then begin
    if MessageDlg('The program removes file after inport.  Are you sure?',
      mtConfirmation,[mbYes,mbCancel],0)=mrCancel then Exit;
  end;
*)
  Prefix:=editPrefix.Text;

  (* Set Keyword string *)
  NoOfItems:=checklistboxKeyWords.Items.Count;
  Keyword:='';
  if NoOfItems>0 then begin
    for I:=0 to NoOfItems-1 do begin
      if checklistboxKeyWords.Checked[I]=True then begin
        if Keyword='' then Keyword:=checklistboxKeyWords.Items[I]
        else Keyword:=Keyword+','+checklistboxKeyWords.Items[I];
      end;
    end;
  end;
  if editKeyword.Text<>'' then begin
    if Keyword='' then Keyword:=editKeyword.Text
    else Keyword:=Keyword+','+editKeyword.Text;
  end;
  if KeyWord='' then KeyWord:='*';

  ResetQuery;
  SetControlStatus(1);
  progressbarInport.Min:=0;
  progressbarInport.Max:=SelectedCount;
  ProcessedCount:=0;
  CancelIt:=False;
  I:=0;
  while (I<=Count-1)and(CancelIt=False) do begin
    if listboxFile.Selected[I]=True then begin
      inc(ProcessedCount);
      FullPath:=listboxFile.Items.Strings[I];
      NameAndExt:=ExtractFileName(FullPath);
      if OpenFile(FullPath)=1 then begin
        if SelectedCount>=2 then begin
          if MessageDlg('Do you skip this image and continue processing?'
            ,mtConfirmation,[mbYes,mbAbort],0)=mrAbort then begin
            CancelIt:=True;
          end;
        end;
        if CancelIt=False and menuOptionRemoveAfterInport.Checked=True then begin
          if MessageDlg('Do you remove the file "'+FullPath+'" ?'
            ,mtConfirmation,[mbYes,mbNo],0)=mrYes then begin
            RemoveFile(FullPath);
          end;
          ResetQuery;
        end;
      end
      else begin
        IsJPEGImage:=imageTmp.Picture.Graphic is TJPEGImage;
        if IsJPEGImage then begin
          if AppendData(FullPath,Prefix,Keyword)=True then begin
            LastName:=NameAndExt;
            formMain.Update;
            formSelector.Update;
            if menuOptionRemoveAfterInport.Checked then begin
               if DeleteFile(FullPath)=False then begin
                 if MessageDlg('Could not remove file "'+FullPath+'".'
                   +chr($0D)+'Do you skip removing this photo file?',
                   mtConfirmation,[mbOK,mbAbort],0)=mrAbort then begin
                   //SetControlStatus(2);
                   //Exit;
                   CancelIt:=True;
                 end;
               end;
            end;
          end
          else begin
            if MessageDlg('Could not write to the database.'
                 +'Do you skip inporting this photo image?'+chr($0D)
                 +'Please remember the last succeeded file name was '
                 + LastName+'.',mtConfirmation,
                [mbYes,mbAbort],0)=mrAbort then begin
                //progressbarInport.Position:=0;
                //SetControlStatus(2);
                //Exit;
              CancelIt:=True;
            end;
          end;
        end
        else begin
          MessageDlg('"'+NameAndExt+'" is not JPEG file.',
            mtInformation,[mbOK],0);
        end;
      end; (* else *)
    end;(* if listboxFile.Selected[I]=True *)
    progressbarInport.Position:=ProcessedCount;
    inc(I);
    Application.ProcessMessages;
  end; (* While *)

  progressbarInport.Position:=0;
  if SelectedCount>=2 then begin
     if CancelIt then MessStr:='Canceled.  Last file name was "'+NameAndExt+'".'
     else MessStr:='Finished';
     MessageDlg(MessStr,mtInformation,[mbOK],0);
  end;
  if menuOptionRemoveAfterInport.Checked=True and (SelectedCount>0) then begin
    listboxFile.Update;
    imageViewArea.Visible:=False;
  end;

  if not(CancelIt) then ResetQuery;

  SetControlStatus(2);
end;



procedure TformSelector.radiogroupScaleClick(Sender: TObject);
var
  Flag : Boolean;
begin
  if radiogroupScale.ItemIndex=0 then Flag:=False
  else Flag:=True;
  menuOptionAutoScale.Checked:=Flag;
  menuOptionAutoScaleClick(Sender);
end;

procedure TformSelector.FormResize(Sender: TObject);
begin
  imgtrans.ImageTransfer(imageTmp,imageViewArea,scrollboxViewArea,True);
  radiogroupScale.ItemIndex:=0;
end;

procedure TformSelector.imageTmpProgress(Sender: TObject;
  Stage: TProgressStage; PercentDone: Byte; RedrawNow: Boolean;
  const R: TRect; const Msg: String);
begin
  if Stage = psRunning then begin
    panelStatusBar.Panels.Items[0].Text:='Loading '+Format('%2d%%',[PercentDone]);
    panelStatusBar.Update;
  end
  else begin
    panelStatusBar.Panels.Items[0].Text:='';
    panelStatusBar.Update;
  end;
end;

procedure TformSelector.menuFileSelectAllClick(Sender: TObject);
var
  Count : Integer;
  I     : Integer;
begin
  Count:=listboxFile.Items.Count;
  bitbtnAppend.Enabled:=True;
  if Count<1 then begin
    MessageDlg('No JPEG file.',mtWarning,[mbOK],0);
    exit;
  end;
  for I:=0 to Count-1 do begin
//messageDlg(listboxFile.Items.Strings[I],mtInformation,[mbOK],0);
    listboxFile.Selected[I]:=True;
  end;
  listboxFile.Refresh;
end;

procedure TformSelector.menuHelpInEngClick(Sender: TObject);
const
  FileName = '..\manual\qr-inportfile.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     main.DisplayResult(Ans, FileName);
end;

procedure TformSelector.menuHelpInJapClick(Sender: TObject);
const
  FileName = '..\manual\qr-inportfile-j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     main.DisplayResult(Ans, FileName);
end;

procedure TformSelector.FormDestroy(Sender: TObject);
begin
  if ExistKey(Global.BaseKeyName) then begin
    StoreFormStatus(formSelector,BaseKeyName);
    StoreOptionStatus;
  end;
end;

procedure TformSelector.menuOptionLayoutClick(Sender: TObject);
begin
  case panelCommand.Align of
    alRight : panelCommand.Align:=alLeft;
    alLeft  : panelCommand.Align:=alRight;
  end;
end;

procedure TformSelector.bitbtnCancelClick(Sender: TObject);
begin
  menuFileCancelInportClick(Sender);
end;

procedure TformSelector.menuOptionAutoScaleClick(Sender: TObject);
begin
  if menuOptionAutoScale.Checked=True then begin
    menuOptionAutoScale.Checked:=False;
    radiogroupScale.ItemIndex:=1;
    imgtrans.ImageTransfer(imageTmp,imageViewArea,scrollboxViewArea,False);
  end
  else begin
    menuOptionAutoScale.Checked:=True;
    radiogroupScale.ItemIndex:=0;
    imgtrans.ImageTransfer(imageTmp,imageViewArea,scrollboxViewArea,True);
  end;
end;

procedure TformSelector.menuOptionRemoveAfterInportClick(Sender: TObject);
var
  Flag : Boolean;
begin
  Flag:=not(menuOptionRemoveAfterInport.Checked);
  menuOptionRemoveAfterInport.Checked:=Flag;
  checkboxRemoveAfterInport.Checked:=Flag;
end;

procedure TformSelector.checkboxRemoveAfterInportClick(Sender: TObject);
var
  Flag : Boolean;
begin
  Flag:=checkboxRemoveAfterInport.Checked;
  menuOptionRemoveAfterInport.Checked:=Flag;
end;

procedure TformSelector.menuFileCancelInportClick(Sender: TObject);
begin
  CancelIt:=True;
end;

procedure TformSelector.FormShow(Sender: TObject);
begin
  LoadKeywordToListBox;
end;

procedure TformSelector.menuEditRefreshListClick(Sender: TObject);
begin
  LoadKeywordToListBox;
end;

end.

